@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-#  Copyright (C) 2016 - 2018 Intel Corporation.
+#  Copyright (C) 2016 - 2019 Intel Corporation.
 #  All rights reserved.
 #
 #  Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@ test -e configure || autoconf
 test -e obj || mkdir obj
 cd obj
 ../configure --enable-autogen --with-jemalloc-prefix=$JE_PREFIX --without-export \
-             --disable-stats --disable-fill \
+             --with-version=5.0.0-0-g0 --disable-fill --disable-initial-exec-tls \
              $EXTRA_CONF --with-malloc-conf="narenas:256,lg_tcache_max:12"
 
 make -j`nproc`
